About — PreciSo documentation

# About

PreciSo is a software written in C++ and developped by Michel Perez and his co-workers. It does classical nucleation and growth theories calculations for precipitation in metallurgical systems.

# Getting Started

- Source code : Gitlab Repository

- To install PreciSo, check out the getting started page.

- To try PreciSo with no installation, go here :

# Authors

- Michel Perez - MichelPerezNet

- Thibaut Chaise

- Arnaud Allera (Python API)

- And many others !

# Contribution and support

Contributions and feedback are welcome. The issue tracker is a great tool to submit questions, support requests and report bugs.

# To cite this project

Perez (M.), Dumont (M.) et Acevedo-Reyes (D.), Implementation of the classical nucleation theory for precipitation, Acta Mater., vol. 56, 2008, p. 2119–2132 (PDF)

# License

This project is licensed under the CECILL licence - see the LICENSE.md file for details

Documentation contents:

- Getting started
  - Contents of this guide
  - Overview
  - How to use PreciSo online (no installation)
  - Installation (local user)
  - Installing PreciSo for developers
- Tutorial
  - Saving Results
- Python API
  - preciso
  - preciso.results
  - preciso.run
  - preciso.HDF5